use sea_orm_migration::prelude::*;

use crate::m20220101_000001_users::User;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Document::Table)
                    .if_not_exists()
                    .col(
                        ColumnDef::new(Document::Id)
                            .string()
                            .not_null()
                            .primary_key(),
                    )
                    .col(ColumnDef::new(Document::User).string().not_null())
                    .col(ColumnDef::new(Document::Device).string().not_null())
                    .col(ColumnDef::new(Document::DeviceId).string().not_null())
                    .col(ColumnDef::new(Document::Percentage).float().not_null())
                    .col(ColumnDef::new(Document::Progress).string().not_null())
                    .col(ColumnDef::new(Document::Timestamp).date_time().not_null())
                    .foreign_key(
                        ForeignKey::create()
                            .name("fk-user-document")
                            .from(Document::Table, Document::User)
                            .to(User::Table, User::Id),
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(Document::Table).to_owned())
            .await
    }
}

#[derive(DeriveIden)]
enum Document {
    Table,
    Id,
    User,
    Device,
    DeviceId,
    Percentage,
    Progress,
    Timestamp,
}
